@@ -1,6 +1,12 @@
 #!/usr/bin/env python
 # coding: utf-8
 
+# In[ ]:
+
+
+#!/usr/bin/env python
+# coding: utf-8
+
 # In[17]:
 
 
@@ -24,9 +30,9 @@ def init(h,p):
         HOST = h
         PORT = p
 
-class server:    
+   
     
-    def start_server(host,port,debug = False):
+def start_server(host,port,debug = False):
 
 
             if debug == True:
@@ -106,10 +112,10 @@ def do(code):
             
             global HOST
             global PORT
-            global ini
+            global init
            
                 
-            if ini == False:
+            if init == False:
                 
                 raise RuntimeError("Client not initialized, run remfunc.init(HOST,PORT) first. You only need to do this once.")
             
@@ -220,5 +226,3 @@ def do(code):
 # In[ ]:
 
 
-
-
